==> pyforchange-2.0.1.tar.gz: pyforchange-2.0.1/README.md <==
Python For Change
=================

Welcome to the community!
-------------------------

Python For Change is a **open source** project. {: .fs-6 .fw-300 }

[Get started
now](https://github.com/PythonForChange/pythonforchange.github.io){:
.btn .btn-primary .fs-5 .mb-4 .mb-md-0 .mr-2 } [View on
Github](https://github.com/PythonForChange){: .btn .fs-5 .mb-4 .mb-md-0
}

### Our software

-   [Covid Plot](https://pythonforchange.github.io/covidplot)
-   [Python For Change
    FilesFormat](https://pythonforchange.github.io/filesformat)

### Installation (last stable version)

1.  Install pyforchange

        pip install pyforchange

2.  Import pyforchange in your python file

    ``` {.python}
    import pyforchange
    ```

3.  Enjoy!

### Contributing

Learn more about how to help others contribute, check out the
[CONTRIBUTING
GUIDELINES](https://pythonforchange.github.io/CodeOfConduct/) for
repository contributors.

### Credits

-   **Emmanuel Norambuena** - *initial work* -
    [Eanorambuena](https://github.com/eanorambuena)
-   **Community** - *contributing*
-   **Andrés Villanueva** - *this web page is based on the README made
    by him* - [Villanuevand](https://github.com/Villanuevand)
-   **Just the Docs** - *this site uses their documentation theme for
    Jekyll* - [View in
    Github](https://github.com/pmarsceill/just-the-docs)

### License

This proyect is under the [MIT
License](https://pythonforchange.github.io/license).

### Made with

-   [Python](https://www.python.org/) - Programming language

### Wiki

You can find much more about how to use this project in our
[Wiki](https://github.com/PythonForChange/pythonforchange.github.io/wiki)
📖

### Support or Contact

Having trouble with Python For Change Software? Check out our
[documentation](https://pythonforchange.github.io/).

* * * * *

⌨️ with ❤️ by [Eanorambuena](https://github.com/eanorambuena) 😊

==> pyforchange-2.0.3.tar.gz: pyforchange-2.0.3/README.md <==
Python For Change
=================

Welcome to the community!
-------------------------

Python For Change is a **open source** project.

[Get started
now](https://github.com/PythonForChange/pythonforchange.github.io)

[View on
Github](https://github.com/PythonForChange)


### Our software

- [Covid Plot](https://pythonforchange.github.io/covidplot)
- [Python For Change Format](https://pythonforchange.github.io/format)
- [Cell](https://pythonforchange.github.io/cell)

### Installation (last stable version)

1.  Install pyforchange

        pip install pyforchange

2.  Import pyforchange in your python file

    ``` {.python}
    import pyforchange
    ```

3.  Enjoy!

### Contributing

Learn more about how to help others contribute, check out the
[CONTRIBUTING
GUIDELINES](https://pythonforchange.github.io/CodeOfConduct/) for
repository contributors.

### Credits

-   **Emmanuel Norambuena** - *initial work* -
    [Eanorambuena](https://github.com/eanorambuena)
-   **Community** - *contributing*
-   **Andrés Villanueva** - *this web page is based on the README made
    by him* - [Villanuevand](https://github.com/Villanuevand)
-   **Just the Docs** - *this site uses their documentation theme for
    Jekyll* - [View in
    Github](https://github.com/pmarsceill/just-the-docs)

### License

This proyect is under the [MIT
License](https://pythonforchange.github.io/license).

### Made with

-   [Python](https://www.python.org/) - Programming language

### Wiki

You can find much more about how to use this project in our
[Wiki](https://github.com/PythonForChange/pythonforchange.github.io/wiki)
📖

### Support or Contact

Having trouble with Python For Change Software? Check out our
[documentation](https://pythonforchange.github.io/).

* * * * *

⌨️ with ❤️ by [Eanorambuena](https://github.com/eanorambuena) 😊
